@@ -1,7 +1,9 @@
 package Perinci::Sub::To::Text;
 
-our $DATE = '2021-02-21'; # DATE
-our $VERSION = '0.875'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-05-23'; # DATE
+our $DIST = 'Perinci-To-Doc'; # DIST
+our $VERSION = '0.876'; # VERSION
 
 use 5.010001;
 use Log::ger;
@@ -75,14 +77,14 @@ sub after_gen_doc {
     $self->add_doc_lines("", __("Return value") . ':');
     $self->inc_doc_indent;
     $self->add_doc_lines(__(
-"Returns an enveloped result (an array).
+'Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information."))
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information.'))
         unless $orig_result_naked;
     $self->add_doc_lines($dres->{res_summary} . ($dres->{res_schema} ? " ($dres->{res_schema}[0])" : "")) if $dres->{res_summary};
 
@@ -106,7 +108,7 @@ Perinci::Sub::To::Text - Generate text documentation from Rinci function metadat
 
 =head1 VERSION
 
-This document describes version 0.875 of Perinci::Sub::To::Text (from Perl distribution Perinci-To-Doc), released on 2021-02-21.
+This document describes version 0.876 of Perinci::Sub::To::Text (from Perl distribution Perinci-To-Doc), released on 2021-05-23.
 
 =head1 SYNOPSIS
 
