@@ -1,7 +1,9 @@
 package Perinci::To::Doc::Role::Section;
 
-our $DATE = '2021-02-21'; # DATE
-our $VERSION = '0.875'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-05-23'; # DATE
+our $DIST = 'Perinci-To-Doc'; # DIST
+our $VERSION = '0.876'; # VERSION
 
 use 5.010;
 use Log::ger;
@@ -111,7 +113,7 @@ Perinci::To::Doc::Role::Section - Role for class that generates documentation wi
 
 =head1 VERSION
 
-This document describes version 0.875 of Perinci::To::Doc::Role::Section (from Perl distribution Perinci-To-Doc), released on 2021-02-21.
+This document describes version 0.876 of Perinci::To::Doc::Role::Section (from Perl distribution Perinci-To-Doc), released on 2021-05-23.
 
 =head1 DESCRIPTION
 
