@@ -1,7 +1,9 @@
 package Perinci::To::Text;
 
-our $DATE = '2021-02-21'; # DATE
-our $VERSION = '0.875'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-05-23'; # DATE
+our $DIST = 'Perinci-To-Doc'; # DIST
+our $VERSION = '0.876'; # VERSION
 
 use 5.010001;
 use Log::ger;
@@ -132,7 +134,7 @@ Perinci::To::Text - Generate text documentation for a package from Rinci metadat
 
 =head1 VERSION
 
-This document describes version 0.875 of Perinci::To::Text (from Perl distribution Perinci-To-Doc), released on 2021-02-21.
+This document describes version 0.876 of Perinci::To::Text (from Perl distribution Perinci-To-Doc), released on 2021-05-23.
 
 =head1 SYNOPSIS
 
